@@ -91,8 +91,11 @@ def addExternalDfnPanel(termEl, ref, elsFromHref, doc):
                                 " ",
                                 E.a({"href": "#" + escapeUrlFrag(linkID), "data-silently-dedup": ""}, "(" + str(i + 1) + ")"))
         appendChild(doc.body, panel)
-        doc.extraScripts['script-dfn-panel'] = dfnPanelScript
-        doc.extraStyles['style-dfn-panel'] = dfnPanelStyle
+
+def addExternalDfnPanelStyles(doc):
+    doc.extraScripts['script-dfn-panel'] = dfnPanelScript
+    doc.extraStyles['style-dfn-panel'] = dfnPanelStyle
+    doc.extraStyles['style-darkmode'] += dfnPanelDarkmodeStyle
 
 
 dfnPanelScript = '''
@@ -152,6 +155,10 @@ document.body.addEventListener("click", function(e) {
 '''
 
 dfnPanelStyle = '''
+:root {
+    --dfnpanel-bg: #ddd;
+    --dfnpanel-text: var(--text);
+}
 .dfn-panel {
     position: absolute;
     z-index: 35;
@@ -163,14 +170,14 @@ dfnPanelStyle = '''
     overflow: auto;
     padding: 0.5em 0.75em;
     font: small Helvetica Neue, sans-serif, Droid Sans Fallback;
-    background: #DDDDDD;
-    color: black;
+    background: var(--dfnpanel-bg);
+    color: var(--dfnpanel-text);
     border: outset 0.2em;
 }
 .dfn-panel:not(.on) { display: none; }
 .dfn-panel * { margin: 0; padding: 0; text-indent: 0; }
 .dfn-panel > b { display: block; }
-.dfn-panel a { color: black; }
+.dfn-panel a { color: var(--dfnpanel-text); }
 .dfn-panel a:not(:hover) { text-decoration: none !important; border-bottom: none !important; }
 .dfn-panel > b + b { margin-top: 0.25em; }
 .dfn-panel ul { padding: 0; }
@@ -187,3 +194,11 @@ dfnPanelStyle = '''
 
 .dfn-paneled { cursor: pointer; }
 '''
+
+dfnPanelDarkmodeStyle = '''
+@media (prefers-color-scheme: dark) {
+    :root {
+        --dfnpanel-bg: #222;
+        --dfnpanel-text: var(--text);
+    }
+}'''
\ No newline at end of file
